import argparse
import os

from bkmrks import bkmrks, md, presenter


def main():
    parser = argparse.ArgumentParser(prog="bkmrks")
    parser.add_argument("--version", action="version", version="%(prog)s v0.1.3")

    subparsers = parser.add_subparsers(dest="command", help="Available commands")
    render_parser = subparsers.add_parser(
        "render",
        help="✍️ Render your html bookmarks to public folder.",
    )

    load_parser = subparsers.add_parser(
        "load",
        help="✍️ Load and HTML file/url and create a bookmark page.",
    )

    load_parser.add_argument(
        "-html",
        help="HTML file/url to scrape.",
    )

    load_parser.add_argument(
        "-catalog",
        help="Bookmark catalog name.",
    )

    args = parser.parse_args()
    if args.command == "render":
        render()

    if args.command == "load":
        bkmrks.html2yaml(html_file_name=args.html, yaml_file_name=args.catalog)
    return


def render():
    bkmrks.ensure_bookmarks_folder()
    presenter.ensure_public_folder()

    bookmarks = os.listdir("bookmarks")
    menu = []
    htmls = []
    for bookmark in bookmarks:
        md_file_name = "public/" + bookmark
        md.generate(md_file_name=md_file_name, yaml_file_name=bookmark)
        htmls.append(presenter.generate_html(md_file_name))
        menu.append(
            presenter.get_file_and_set_variable(
                file="templates/menu_item.html",
                variable="menu_item",
                content=bookmark.split(".")[0],
            )
        )
    menu = " | ".join(menu)
    for html in htmls:
        html_content = presenter.get_file_and_set_variable(
            file=html,
            variable="menu",
            content=menu,
        )
        with open(html, "+w") as f:
            f.write(html_content)


if __name__ == "__main__":
    main()



import os
from urllib.parse import urlparse

import requests
import yaml
from bs4 import BeautifulSoup

from bkmrks.urls import ensure_domain, get_url_icon


def get(file_name="index"):
    ensure_bookmarks_folder()
    file_name = file_name.split(".")[0] + ".yaml"
    with open(f"bookmarks/{file_name}", "r") as f:
        return yaml.safe_load(f.read())


def set_yaml(data, file_name="index"):
    ensure_bookmarks_folder()
    file_name = file_name.split(".")[0] + ".yaml"
    with open(f"bookmarks/{file_name}", "+w") as f:
        yaml.dump(data, f)
        f.seek(0)
    return get(file_name=file_name)


def html2yaml(html_file_name, yaml_file_name):
    if str(html_file_name).startswith("https://"):
        html = requests.get(html_file_name).text
        url_parse = urlparse(html_file_name)
        domain = "://".join([url_parse.scheme, url_parse.netloc])

    else:
        domain = ""
        html_file_name = html_file_name.split(".")[0] + ".html"
        with open(html_file_name, "r") as f:
            html = f.read()

    r = BeautifulSoup(html, features="html.parser")
    a = r.find_all(["hr", "a"])

    l = 0
    b = 1
    yaml_data = {}

    for item in a:
        if len(item.attrs) == 0 or l == 0:
            l += 1
            b = 0
            yaml_data[f"l{l}"] = {}
        elif item.has_attr("href") and not item["href"].startswith("#"):
            item["href"] = ensure_domain(url=item["href"], domain=domain)

            b += 1
            href_parse = urlparse(item["href"])
            has_img = False
            if len(item.find_all("img")) > 0:
                if len(item.find("img")["src"]) < 200:
                    has_img = False
            if has_img:
                img = item.find("img")["src"]
            else:
                img = get_url_icon(item["href"])
            url = item["href"]
            name = href_parse.netloc.split(".")

            if name[-2] == "google":
                name = "_".join(name[:-1][::-1])
            else:
                name = name[-2]
            item = {}
            item["name"] = name
            item["url"] = url
            item["img"] = img

            yaml_data[f"l{l}"][f"b{b}"] = item.copy()

    set_yaml(data=yaml_data, file_name=yaml_file_name)


def ensure_bookmarks_folder():
    if not os.path.exists("bookmarks"):
        os.mkdir("bookmarks")
        data = {
            "l1": {
                "b1": {
                    "name": "bkmrks_page",
                    "img": "https://cesarcardoso.cc/README/1_bouli.png",
                    "url": "https://github.com/bouli/bkmrks",
                }
            }
        }
        set_yaml(data=data)
